*System Options;
options mprint linesize=150 pagesize=50 compress=yes symbolgen ERRORS=0;

/***********************/
/*    User Inputs      */
/***********************/

*Edit this section to reflect locations for the Libraries and Folders for Mini-Sentinel;
*IMPORTANT NOTE: end of path separators are needed;
*	Windows-based platforms: 	"\", e.g. "C:\user\sas\" and not "C:\user\sas";
*	Unix-based platforms:		"/", e.g."/home/user/sas/" and not "/home/user/sas";

/********** FOLDER CONTAINING INPUT DATA FILES AND MSCDM DATA ***************************************/;
/*Data in MSCDM Format*/          libname indata 'C:\Harvard\ToolKit\ms_agestrat\indata\';		

/*********** FOLDER CONTAINING FINAL DATASETS TO BE KEPT LOCAL AT THE PARTNER SITE (DPLocal)**********/;
/*SAS Output Files*/              libname outdata 'C:\Harvard\ToolKit\ms_agestrat\outdata\';	

/*********** FOLDER CONTAINING the sas macro **********/;
/*Macro location */               %include "C:\Harvard\ToolKit\ms_agestrat\ms_agestrat.sas"; 

/********************************************END OF USER INPUT**********************************************/

/*Example 1: Using the AgeStrat tool to calculate the patients's age on January 1st, 2011 */
/*           The start date is the birth date                                             */
/*           The end date is initialized as a constant for all observation 01/01/2011     */
/*           The time vector uses a mix of days, weeks, months, quarters and years        */

%MS_AGESTRAT(INFILE=indata.ms_agestrat_demographic,                       /*Input file containing start date (required)*/
		     OUTFILE=outdata.ms_agestrat_example1,                        /*Output file*/  
		     STARTDT=birth_date,                                          /*Start date to measure age*/
		     ENDDT=01/01/2011,                                            /*End date to measure age*/
 		     TIMESTRAT=0D-6D 1W-3W 1M-2M 1Q-2Q 7M-11M 1Y-2Y 3Y-5Y 6Y+);   /*Age groups for stratification*/


/*Example 2: Using the AgeStrat tool to calculate the patients's age at a diagnosis date (ADATE) */
/*           The start date is the birth date                                                    */
/*           The end date is the diagnosis date (ADATE)                                          */
/*           No time vector is specified therefore the default value will be used                */
/*           (00-01 02-04 05-09 10-14 15-18 19-21 22-44 45-64 65-74 75+ YEARS)                   */

%MS_AGESTRAT(INFILE=indata.ms_agestrat_demo_diagnosis,                    /*Input file containing start date (required)*/
		     OUTFILE=outdata.ms_agestrat_example2,                        /*Output file*/  
		     STARTDT=birth_date,                                          /*Start date to measure age*/
		     ENDDT=adate,                                                 /*End date to measure age*/
 		     TIMESTRAT=);                                                 /*Age groups for stratification*/
 
